#!/usr/bin/env bash
set -euo pipefail

REPO_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
ENV_FILE="$REPO_DIR/.env"

if [ -f "$ENV_FILE" ]; then
  echo "♻️  Found existing $ENV_FILE — reusing."
else
  echo "🔐 Generating new $ENV_FILE…"

  # ── Database defaults
  DB_USER="postgres"
  DB_PASS="$(openssl rand -hex 16)"
  DB_NAME="lnbitsdb"
  DATABASE_URL="postgresql://${DB_USER}:${DB_PASS}@db:5432/${DB_NAME}"

  # ── Flask UI secret
  FLASK_SECRET="$(openssl rand -hex 32)"

  # ── Blank placeholders for the Web UI to fill later
  cat > "$ENV_FILE" <<EOF
# ── Database
DB_USER=${DB_USER}
DB_PASS=${DB_PASS}
DB_NAME=${DB_NAME}
DATABASE_URL=${DATABASE_URL}

# ── Flask UI
FLASK_SECRET=${FLASK_SECRET}

# ── Discord Bot (edit via Web UI or manually here)
DISCORD_TOKEN=
GUILD_ID=
ROLE_ID=
CHANNEL_ID=
LNBITS_URL=
LNBITS_API_KEY=
PRICE=1000
COMMAND_NAME=support
INVOICE_MESSAGE=Thank you for supporting us!
EOF

  echo "✅ Wrote defaults to $ENV_FILE"
fi

echo
echo "🚀 Bringing up all services…"
docker-compose up -d --build

echo
echo "🔐 Your DB credentials (in .env):"
echo "   DB_USER: $DB_USER"
echo "   DB_PASS: $DB_PASS"
echo "   DB_NAME: $DB_NAME"
echo
echo "🔑 Your Flask secret: $FLASK_SECRET"
echo
echo "🌐 Web UI available at http://localhost:3000"
